##
##  nghttp3.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base 1.7.0
%define       V_snap 20241219

#   package information
Name:         nghttp3
Summary:      HTTP/3 & QUIC/QPACK C Library
URL:          https://github.com/ngtcp2/nghttp3
Vendor:       nghttp3 Contributors
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MIT
Version:      %{V_base}
Release:      20241219

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/nghttp3/nghttp3-%{V_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, cmake
PreReq:       OpenPKG, openpkg >= 20160101

%description
    nghttp3 is an implementation of HTTP/3 mapping over QUIC and QPACK
    in C. This library implements HTTP/3 draft-31. It can exchange basic
    HTTP request, response and server push, but does not fully implement
    the specification at the moment.

%track
    prog nghttp3 = {
        version   = %{V_base}
        url       = https://github.com/ngtcp2/nghttp3/releases
        regex     = tree/v(__VER__)
    }

%prep
    %setup -q -n nghttp3

%build
    mkdir build
    cd build
    cmake \
        -Wno-dev \
        -DCMAKE_BUILD_TYPE="Release" \
        -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
        -DCMAKE_C_COMPILER="%{l_cc}" \
        -DCMAKE_C_FLAGS="%{l_cflags} %{l_cppflags}" \
        -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags}" \
        -DCMAKE_CXX_COMPILER="%{l_cxx}" \
        -DENABLE_SHARED_LIB=OFF \
        -DENABLE_LIB_ONLY=ON \
        ..
    %{l_make} %{l_mflags -O}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig \
        $RPM_BUILD_ROOT%{l_prefix}/include/nghttp3
    %{l_shtool} install -c -m 644 \
        build/lib/libnghttp3.a $RPM_BUILD_ROOT%{l_prefix}/lib/
    %{l_shtool} install -c -m 644 \
        build/lib/libnghttp3.pc $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig/
    %{l_shtool} install -c -m 644 \
        lib/includes/nghttp3/nghttp3.h \
        build/lib/includes/nghttp3/version.h \
        $RPM_BUILD_ROOT%{l_prefix}/include/nghttp3/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

